
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw3d/List.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvFont.h>
#include <X11/xv/xvList.h>

// -------------------------------------------

xvList::xvList()
{
	alloc=FALSE;
}

// -------------------------------------------

xvList::xvList(String name, xvCore & parent, XtCallbackProc callback, 
			int numdata, char **listdata, int columns)
{
	init(name, parent, callback, numdata, listdata, columns);
}

// -------------------------------------------

xvList::~xvList()
{
	if (alloc) XtDestroyWidget(w);
}

// -------------------------------------------

void xvList::init(String name, xvCore & parent, XtCallbackProc callback, 
				int numdata, char **listdata, int columns)
{
	init(name, parent.ID(), callback, numdata, listdata, columns);

}

// ------------------------------------------

void xvList::init(String name, Widget parent, XtCallbackProc callback, 
				int numdata, char **listdata, int columns)
{
	w=XtVaCreateManagedWidget(name, listWidgetClass, parent,
		"defaultColumns", columns,
		"forceColumns", TRUE,
		"list", listdata,
		"numberStrings", numdata,
		NULL);
	XtAddCallback(w, XtNcallback, callback, 0);
	alloc=TRUE;
	bfont.init(w, NULL);

}

// ------------------------------------------

void xvList::ChangeFont(String fontname)
{
	bfont.FLoadFont(fontname);
	XtVaSetValues(w, XtNfont, (XtArgVal) bfont.FontRef(), NULL);
}

// -----------------------------------------------------------------

void xvList::SetList(int numdata, char **listdata)
{
	XawListChange(w, listdata, numdata, 0, TRUE);

}

// ------------------------------------------

void xvList::Highlight(int item)
{
	XawListHighlight(w, item);
}

// ------------------------------------------

void xvList::Unhighlight()
{
	XawListUnhighlight(w);
}

// ------------------------------------------

XawListReturnStruct *xvList::ShowCurrent()
{
	return(XawListShowCurrent(w));
}

// -------------------------------------------

int xvList::GetLongest()
{
	int l;
	XtVaGetValues(w, XtNlongest, &l, NULL);
	return(l);
}

// -------------------------------------------
